@@ -1,4 +1,4 @@
-// $Id: syscall_rlimit.c,v 1.1.2.2 2003/12/30 13:45:56 ensc Exp $    --*- c++ -*--
+// $Id: syscall_rlimit.c,v 1.4 2004/01/21 18:55:12 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -22,31 +22,47 @@
 #include "compat.h"
 
 #include "vserver.h"
-#include "vserver-internal.h"
+#include "internal.h"
 #include "linuxvirtual.h"
 
-#ifdef VC_ENABLE_API_V11
+
+#include "vserver-internal.h"
+
+#if defined(VC_ENABLE_API_V11) || defined(VC_ENABLE_API_V13)
 #  include "syscall_rlimit-v11.hc"
 #endif
 
-#if defined (VC_ENABLE_API_V11)
+#ifdef VC_ENABLE_API_V13
+#  define vc_get_rlimit_v13		vc_get_rlimit_v11
+#  define vc_set_rlimit_v13		vc_set_rlimit_v11
+#  define vc_get_rlimit_mask_v13	vc_get_rlimit_mask_v11
+#endif
+
+
+#if defined(VC_ENABLE_API_V11) || defined(VC_ENABLE_API_V13)
+
+  // NOTICE: the reverse order of V11 -> V13 is correct here since these are
+  // the same syscalls
 
 int
 vc_get_rlimit(xid_t ctx, int resource, struct vc_rlimit *lim)
 {
-  CALL_VC(CALL_VC_V11(vc_get_rlimit, ctx, resource, lim));
+  CALL_VC(CALL_VC_V11(vc_get_rlimit, ctx, resource, lim),
+	  CALL_VC_V13(vc_get_rlimit, ctx, resource, lim));
 }
 
 int
 vc_set_rlimit(xid_t ctx, int resource, struct vc_rlimit const *lim)
 {
-  CALL_VC(CALL_VC_V11(vc_set_rlimit, ctx, resource, lim));
+  CALL_VC(CALL_VC_V11(vc_set_rlimit, ctx, resource, lim),
+	  CALL_VC_V13(vc_set_rlimit, ctx, resource, lim));
 }
 
 int
 vc_get_rlimit_mask(xid_t ctx, struct vc_rlimit_mask *lim)
 {
-  CALL_VC(CALL_VC_V11(vc_get_rlimit_mask, ctx, 0, lim));
+  CALL_VC(CALL_VC_V11(vc_get_rlimit_mask, ctx, 0, lim),
+	  CALL_VC_V13(vc_get_rlimit_mask, ctx, 0, lim));
 }
     
 
